==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Widgets/LibraryBrowser/ts/LibraryBrowser_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>Favorites</name>
    <message>
        <source>Item &apos;%1&apos; has been added to your favorites.</source>
        <translation type="obsolete">Objekt &apos;%1&apos; wurde den Favoriten hinzugefügt.</translation>
    </message>
</context>
<context>
    <name>LibraryBrowser</name>
    <message>
        <location filename="../LibraryBrowser.js" line="+69"/>
        <source>audience</source>
        <translation>Zielgruppe</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>creator</source>
        <translation>Autor</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>dimension</source>
        <translation>Dimension</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>levelOfDetail</source>
        <translation>Detaillierungsgrad</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>license</source>
        <translation>Lizenz</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>perspective</source>
        <translation>Perspektive</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>presentation</source>
        <translation>Präsentation</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>publisher</source>
        <translation>Verleger</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>subject</source>
        <translation>Thema</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Widgets</source>
        <translation>Widgets</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+1105"/>
        <location filename="../LibraryBrowserInit.js" line="+18"/>
        <source>Library Browser</source>
        <translation>Bibliothekbrowser</translation>
    </message>
    <message>
        <location line="-1097"/>
        <source>Icon</source>
        <translation>Ikone</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>List</source>
        <translation>Liste</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Choose Source Folder</source>
        <translation>Quellordner wählen</translation>
    </message>
    <message>
        <location line="+652"/>
        <source>Page %1 of %2</source>
        <translation>Seite %1 von %2</translation>
    </message>
    <message>
        <location line="+219"/>
        <source>Updating icons...</source>
        <translation>Ikone generieren...</translation>
    </message>
    <message>
        <location line="+193"/>
        <source>File:</source>
        <translation>Datei:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Folder:</source>
        <translation>Ordner:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>License:</source>
        <translation>Lizenz:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Attribute as:</source>
        <translation>Namensnennung als:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Creator:</source>
        <translation>Autor:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Updating library index:</source>
        <translation>Aktualisiere Index:</translation>
    </message>
    <message>
        <source>Updating index...</source>
        <translation type="obsolete">Aktualisiere Index...</translation>
    </message>
    <message>
        <location line="-218"/>
        <location line="+219"/>
        <source>Abort</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Updating index:</source>
        <translation type="obsolete">Aktualisiere Index:</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>DB error</source>
        <translation>DB Error</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plugin LibraryBrowser: cannot connect to DB.
Driver error: %1
Database error: %2
Database file: %3
Library browser will not be available.</source>
        <translation>Plugin LibraryBrowser: cannot connect to DB.
Driver error: %1
Database error: %2
Database file: %3
Library browser will not be available.</translation>
    </message>
    <message>
        <location line="+446"/>
        <source>&amp;Insert</source>
        <translation>&amp;Einfügen</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Edit Script File...</source>
        <translation>&amp;Skript Datei bearbeiten...</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Open &amp;SVG File...</source>
        <translation>&amp;SVG Datei öffnen...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;Open...</source>
        <translation>Ö&amp;ffnen...</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>&amp;Edit...</source>
        <translation>&amp;Bearbeiten...</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>File Browser</source>
        <translation>Ordner</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>&amp;Show in %1...</source>
        <translation>&amp;Anzeigen im %1...</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>&amp;Remove from Favorites</source>
        <translation>&amp;Entfernen aus Favoriten</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Add to Favorites</source>
        <translation>An Favoriten &amp;hinzufügen</translation>
    </message>
    <message>
        <location line="+34"/>
        <source>&amp;Regenerate Icon</source>
        <translation>&amp;Ikon neu generieren</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Regenerate Icons</source>
        <translation>Ikone neu &amp;generieren</translation>
    </message>
    <message>
        <source>Preferences</source>
        <translation type="obsolete">Einstellungen</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Synchronization</source>
        <translation>Synchronisation</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Update search index on startup</source>
        <translation>Suchindex beim Start aktualisieren</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Display Options</source>
        <translation>Anzeigeoptionen</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Icon Size:</source>
        <translation>Symbolgrösse:</translation>
    </message>
    <message>
        <location line="+44"/>
        <source>View Mode:</source>
        <translation>Anzeigemodus:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Number of items
shown in search results:</source>
        <translation>Anzahl Einträge
im Suchresultat:</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Library Sources</source>
        <translation>Bibliothekquellen</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Add...</source>
        <translation>Hinzufügen...</translation>
    </message>
    <message>
        <source>Add ...</source>
        <translation type="obsolete">Hinzufügen...</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Up</source>
        <translation>Nach oben</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Down</source>
        <translation>Nach unten</translation>
    </message>
    <message>
        <location filename="../LibraryBrowserInit.js" line="-10"/>
        <source>&amp;Library Browser</source>
        <translation>&amp;Bibliothekbrowser</translation>
    </message>
</context>
<context>
    <name>LibraryBrowserForm</name>
    <message>
        <location filename="../LibraryBrowser.ui" line="+28"/>
        <source>File System</source>
        <translation>Dateisystem</translation>
    </message>
    <message>
        <location line="+252"/>
        <source>Favorites</source>
        <translation>Favoriten</translation>
    </message>
    <message>
        <location line="-201"/>
        <source>Tags</source>
        <translation>Tags</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Look for:</source>
        <translation>Suchen nach:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Clear</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Find</source>
        <translation>Suchen</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Reset tag selection</source>
        <translation>Tags zurücksetzen</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>about:blank</source>
        <translation>about:blank</translation>
    </message>
    <message>
        <location line="+157"/>
        <source>Update DB from file system</source>
        <translation>Aktualisieren von Dateisystem</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>0</source>
        <translation>0</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Widgets/LibraryBrowser/ts/LibraryBrowser_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>Favorites</name>
    <message>
        <source>Item &apos;%1&apos; has been added to your favorites.</source>
        <translation type="obsolete">Objekt &apos;%1&apos; wurde den Favoriten hinzugefügt.</translation>
    </message>
</context>
<context>
    <name>LibraryBrowser</name>
    <message>
        <location filename="../LibraryBrowser.js" line="+71"/>
        <source>audience</source>
        <translation>Zielgruppe</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>creator</source>
        <translation>Autor</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>dimension</source>
        <translation>Dimension</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>levelOfDetail</source>
        <translation>Detaillierungsgrad</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>license</source>
        <translation>Lizenz</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>perspective</source>
        <translation>Perspektive</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>presentation</source>
        <translation>Präsentation</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>publisher</source>
        <translation>Verleger</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>subject</source>
        <translation>Thema</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Widgets</source>
        <translation>Widgets</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+1153"/>
        <location filename="../LibraryBrowserInit.js" line="+19"/>
        <source>Library Browser</source>
        <translation>Bibliothekbrowser</translation>
    </message>
    <message>
        <location line="-1145"/>
        <source>Icon</source>
        <translation>Ikone</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>List</source>
        <translation>Liste</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Choose Source Folder</source>
        <translation>Quellordner wählen</translation>
    </message>
    <message>
        <location line="+685"/>
        <source>Page %1 of %2</source>
        <translation>Seite %1 von %2</translation>
    </message>
    <message>
        <location line="+235"/>
        <source>Updating icons...</source>
        <translation>Ikone generieren...</translation>
    </message>
    <message>
        <location line="+193"/>
        <source>File:</source>
        <translation>Datei:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Folder:</source>
        <translation>Ordner:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>License:</source>
        <translation>Lizenz:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Attribute as:</source>
        <translation>Namensnennung als:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Creator:</source>
        <translation>Autor:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Updating library index:</source>
        <translation>Aktualisiere Index:</translation>
    </message>
    <message>
        <source>Updating index...</source>
        <translation type="obsolete">Aktualisiere Index...</translation>
    </message>
    <message>
        <location line="-218"/>
        <location line="+219"/>
        <source>Abort</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Updating index:</source>
        <translation type="obsolete">Aktualisiere Index:</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>DB error</source>
        <translation>DB Error</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plugin LibraryBrowser: cannot connect to DB.
Driver error: %1
Database error: %2
Database file: %3
Library browser will not be available.</source>
        <translation>Plugin LibraryBrowser: cannot connect to DB.
Driver error: %1
Database error: %2
Database file: %3
Library browser will not be available.</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Source removed from part library: %1</source>
        <translation>Quelle entfernt von Teilebibliothek: %1</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Force database update.</source>
        <translation>Erzwungene Aktualisierung der Datenbank.</translation>
    </message>
    <message>
        <location line="+393"/>
        <source>&amp;Insert</source>
        <translation>&amp;Einfügen</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Edit Script File...</source>
        <translation>&amp;Skript Datei bearbeiten...</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Open &amp;SVG File...</source>
        <translation>&amp;SVG Datei öffnen...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;Open...</source>
        <translation>Ö&amp;ffnen...</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>&amp;Edit...</source>
        <translation>&amp;Bearbeiten...</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>File Browser</source>
        <translation>Dateibrowser</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>&amp;Show in %1...</source>
        <translation>&amp;Anzeigen im %1...</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>&amp;Remove from Favorites</source>
        <translation>&amp;Entfernen aus Favoriten</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Add to Favorites</source>
        <translation>An Favoriten &amp;hinzufügen</translation>
    </message>
    <message>
        <location line="+34"/>
        <source>&amp;Regenerate Icon</source>
        <translation>&amp;Ikon neu generieren</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Regenerate Icons</source>
        <translation>Ikone neu &amp;generieren</translation>
    </message>
    <message>
        <source>Preferences</source>
        <translation type="obsolete">Einstellungen</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Synchronization</source>
        <translation>Synchronisation</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Update search index on startup</source>
        <translation>Suchindex beim Start aktualisieren</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Display Options</source>
        <translation>Anzeigeoptionen</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Icon Size:</source>
        <translation>Symbolgrösse:</translation>
    </message>
    <message>
        <location line="+44"/>
        <source>View Mode:</source>
        <translation>Anzeigemodus:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Number of items
shown in search results:</source>
        <translation>Anzahl Einträge
im Suchresultat:</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Library Sources</source>
        <translation>Bibliothekquellen</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Add...</source>
        <translation>Hinzufügen...</translation>
    </message>
    <message>
        <source>Add ...</source>
        <translation type="obsolete">Hinzufügen...</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Up</source>
        <translation>Nach oben</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Down</source>
        <translation>Nach unten</translation>
    </message>
    <message>
        <location filename="../LibraryBrowserInit.js" line="-11"/>
        <source>&amp;Library Browser</source>
        <translation>&amp;Bibliothekbrowser</translation>
    </message>
</context>
<context>
    <name>LibraryBrowserForm</name>
    <message>
        <location filename="../LibraryBrowser.ui" line="+28"/>
        <source>File System</source>
        <translation>Dateisystem</translation>
    </message>
    <message>
        <location line="+60"/>
        <source>Search</source>
        <translation>Suchen</translation>
    </message>
    <message>
        <location line="+197"/>
        <source>Favorites</source>
        <translation>Favoriten</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation type="vanished">Tags</translation>
    </message>
    <message>
        <location line="-174"/>
        <source>Look for:</source>
        <translation>Suchen nach:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Clear</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Find</source>
        <translation>Suchen</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Reset tag selection</source>
        <translation>Tags zurücksetzen</translation>
    </message>
    <message>
        <source>about:blank</source>
        <translation type="vanished">about:blank</translation>
    </message>
    <message>
        <location line="+162"/>
        <source>Insert selected item into drawing</source>
        <translation>Ausgewähltes Objekt in Zeichnung einfügen</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Update DB from file system</source>
        <translation>Aktualisieren von Dateisystem</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>0</source>
        <translation>0</translation>
    </message>
</context>
</TS>
